tier.component
tier.component(kind, *, default=None)The imported object filling kind, or default when it is absent.
The degrade-gracefully form of :func:require: the overlay and the exporter ask for the object and fall back when they get None.